# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: radiens_dev.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='radiens_dev.proto',
  package='allego',
  syntax='proto2',
  serialized_options=b'Z\023internal/radix/grpc',
  serialized_pb=b'\n\x11radiens_dev.proto\x12\x06\x61llego\"\xc0\x01\n\x14SpkSortTrainerNewReq\x12\x33\n\x07\x64\x61taset\x18\x01 \x02(\x0b\x32\".allego.SpkSortTrainerDatasetParam\x12=\n\x08training\x18\x02 \x02(\x0b\x32+.allego.SpkSortTrainerNetworkTrainingParams\x12\x34\n\x05store\x18\x03 \x02(\x0b\x32%.allego.SpkSortTrainerStoreDescriptor\"l\n\x1cSpkSortTrainerDeleteModelReq\x12\x35\n\x07release\x18\x01 \x01(\x0e\x32$.allego.SpkSortTrainerNetworkRelease\x12\x15\n\risDeleteNamed\x18\x02 \x01(\x08\"\xb6\x03\n\x1aSpkSortTrainerDatasetParam\x12\x14\n\x0c\x62ioPathTrain\x18\x01 \x03(\t\x12\x18\n\x10\x62ioBaseNameTrain\x18\x02 \x03(\t\x12\x19\n\x11\x62ioPathValidation\x18\x03 \x03(\t\x12\x1d\n\x15\x62ioBaseNameValidation\x18\x04 \x03(\t\x12\x13\n\x0b\x62ioPathTest\x18\x05 \x03(\t\x12\x17\n\x0f\x62ioBaseNameTest\x18\x06 \x03(\t\x12\x14\n\x0cnumNeighbors\x18\x07 \x02(\x05\x12\x10\n\x08radiusUm\x18\x08 \x02(\x01\x12\x19\n\x11maxNumSamplesTest\x18\t \x02(\x03\x12\x1a\n\x12networkMaskingFrac\x18\n \x02(\x01\x12 \n\x18networkInitWeightsStdDev\x18\x0b \x02(\x01\x12\x1d\n\x15networkInitBiasStdDev\x18\x0c \x02(\x01\x12\x17\n\x0fnetworkL1lambda\x18\r \x02(\x01\x12*\n\"networkHiddenLayerShapeRelInputDim\x18\x0e \x03(\x01\x12\x1b\n\x13networkNumFeatures2\x18\x0f \x02(\x05\"\xbd\x01\n#SpkSortTrainerNetworkTrainingParams\x12\x11\n\tnumEpochs\x18\x01 \x02(\x05\x12\x15\n\rminibatchSize\x18\x02 \x02(\x05\x12\x15\n\rmaxNumSamples\x18\x03 \x02(\x03\x12\r\n\x05\x61lpha\x18\x04 \x02(\x01\x12\x11\n\talphaBias\x18\x05 \x02(\x01\x12\x18\n\x10\x65rrorTolPretrain\x18\x06 \x02(\x01\x12\x19\n\x11numSamplesTestMSE\x18\x07 \x02(\x05\"\x87\x02\n\x1dSpkSortTrainerStoreDescriptor\x12\x13\n\x0b\x62rainRegion\x18\x01 \x02(\t\x12\x36\n\x0bnetworkSize\x18\x02 \x02(\x0e\x32!.allego.SpkSortTrainerNetworkSize\x12\x39\n\nnbrPattern\x18\x03 \x02(\x0e\x32%.allego.SpkSortTrainerNeighborPattern\x12\x11\n\tnetworkID\x18\x04 \x02(\t\x12\x14\n\x0cnumNeighbors\x18\x05 \x02(\x05\x12\x35\n\x07release\x18\x06 \x02(\x0e\x32$.allego.SpkSortTrainerNetworkRelease\"(\n\x18SpkSortTrainerSetModeReq\x12\x0c\n\x04mode\x18\x01 \x02(\x05\"\x81\x01\n\x14SpkSortTrainerCmdReq\x12;\n\x03\x63md\x18\x01 \x02(\x0e\x32..allego.SpkSortTrainerCmdReq.SpkSortTrainerCmd\",\n\x11SpkSortTrainerCmd\x12\n\n\x06\x43MD_ON\x10\x00\x12\x0b\n\x07\x43MD_OFF\x10\x01\",\n\x19SpkSortTrainerStatusReply\x12\x0f\n\x07msgJson\x18\x01 \x02(\x0c*\x81\x01\n\x19SpkSortTrainerNetworkSize\x12\x14\n\x10SST_SIZE_DEFAULT\x10\x00\x12\x10\n\x0cSST_SIZE_ARB\x10\x01\x12\x12\n\x0eSST_SIZE_SMALL\x10\x02\x12\x14\n\x10SST_SIZE_NOMINAL\x10\x03\x12\x12\n\x0eSST_SIZE_LARGE\x10\x04*\xa1\x01\n\x1dSpkSortTrainerNeighborPattern\x12\x17\n\x13SST_PATTERN_DEFAULT\x10\x00\x12\x13\n\x0fSST_PATTERN_ARB\x10\x01\x12\x14\n\x10SST_PATTERN_DIST\x10\x02\x12\x1d\n\x19SST_PATTERN_SPATIAL_TIGHT\x10\x03\x12\x1d\n\x19SST_PATTERN_SPATIAL_LOOSE\x10\x04*\xe3\x01\n\x1cSpkSortTrainerNetworkRelease\x12\x17\n\x13SST_NET_RELEASE_ANY\x10\x00\x12\x17\n\x13SST_NET_RELEASE_DEV\x10\x01\x12\x1b\n\x17SST_NET_RELEASE_DEV_MOD\x10\x02\x12\x18\n\x14SST_NET_RELEASE_PROD\x10\x03\x12\x1c\n\x18SST_NET_RELEASE_PROD_MOD\x10\x04\x12\x1b\n\x17SST_NET_RELEASE_SANDBOX\x10\x05\x12\x1f\n\x1bSST_NET_RELEASE_SANDBOX_MOD\x10\x06\x42\x15Z\x13internal/radix/grpc'
)

_SPKSORTTRAINERNETWORKSIZE = _descriptor.EnumDescriptor(
  name='SpkSortTrainerNetworkSize',
  full_name='allego.SpkSortTrainerNetworkSize',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SST_SIZE_DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SST_SIZE_ARB', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SST_SIZE_SMALL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SST_SIZE_NOMINAL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SST_SIZE_LARGE', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1454,
  serialized_end=1583,
)
_sym_db.RegisterEnumDescriptor(_SPKSORTTRAINERNETWORKSIZE)

SpkSortTrainerNetworkSize = enum_type_wrapper.EnumTypeWrapper(_SPKSORTTRAINERNETWORKSIZE)
_SPKSORTTRAINERNEIGHBORPATTERN = _descriptor.EnumDescriptor(
  name='SpkSortTrainerNeighborPattern',
  full_name='allego.SpkSortTrainerNeighborPattern',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SST_PATTERN_DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SST_PATTERN_ARB', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SST_PATTERN_DIST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SST_PATTERN_SPATIAL_TIGHT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SST_PATTERN_SPATIAL_LOOSE', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1586,
  serialized_end=1747,
)
_sym_db.RegisterEnumDescriptor(_SPKSORTTRAINERNEIGHBORPATTERN)

SpkSortTrainerNeighborPattern = enum_type_wrapper.EnumTypeWrapper(_SPKSORTTRAINERNEIGHBORPATTERN)
_SPKSORTTRAINERNETWORKRELEASE = _descriptor.EnumDescriptor(
  name='SpkSortTrainerNetworkRelease',
  full_name='allego.SpkSortTrainerNetworkRelease',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SST_NET_RELEASE_ANY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SST_NET_RELEASE_DEV', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SST_NET_RELEASE_DEV_MOD', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SST_NET_RELEASE_PROD', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SST_NET_RELEASE_PROD_MOD', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SST_NET_RELEASE_SANDBOX', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SST_NET_RELEASE_SANDBOX_MOD', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1750,
  serialized_end=1977,
)
_sym_db.RegisterEnumDescriptor(_SPKSORTTRAINERNETWORKRELEASE)

SpkSortTrainerNetworkRelease = enum_type_wrapper.EnumTypeWrapper(_SPKSORTTRAINERNETWORKRELEASE)
SST_SIZE_DEFAULT = 0
SST_SIZE_ARB = 1
SST_SIZE_SMALL = 2
SST_SIZE_NOMINAL = 3
SST_SIZE_LARGE = 4
SST_PATTERN_DEFAULT = 0
SST_PATTERN_ARB = 1
SST_PATTERN_DIST = 2
SST_PATTERN_SPATIAL_TIGHT = 3
SST_PATTERN_SPATIAL_LOOSE = 4
SST_NET_RELEASE_ANY = 0
SST_NET_RELEASE_DEV = 1
SST_NET_RELEASE_DEV_MOD = 2
SST_NET_RELEASE_PROD = 3
SST_NET_RELEASE_PROD_MOD = 4
SST_NET_RELEASE_SANDBOX = 5
SST_NET_RELEASE_SANDBOX_MOD = 6


_SPKSORTTRAINERCMDREQ_SPKSORTTRAINERCMD = _descriptor.EnumDescriptor(
  name='SpkSortTrainerCmd',
  full_name='allego.SpkSortTrainerCmdReq.SpkSortTrainerCmd',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CMD_ON', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CMD_OFF', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1361,
  serialized_end=1405,
)
_sym_db.RegisterEnumDescriptor(_SPKSORTTRAINERCMDREQ_SPKSORTTRAINERCMD)


_SPKSORTTRAINERNEWREQ = _descriptor.Descriptor(
  name='SpkSortTrainerNewReq',
  full_name='allego.SpkSortTrainerNewReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset', full_name='allego.SpkSortTrainerNewReq.dataset', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='training', full_name='allego.SpkSortTrainerNewReq.training', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='store', full_name='allego.SpkSortTrainerNewReq.store', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30,
  serialized_end=222,
)


_SPKSORTTRAINERDELETEMODELREQ = _descriptor.Descriptor(
  name='SpkSortTrainerDeleteModelReq',
  full_name='allego.SpkSortTrainerDeleteModelReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='release', full_name='allego.SpkSortTrainerDeleteModelReq.release', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isDeleteNamed', full_name='allego.SpkSortTrainerDeleteModelReq.isDeleteNamed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=332,
)


_SPKSORTTRAINERDATASETPARAM = _descriptor.Descriptor(
  name='SpkSortTrainerDatasetParam',
  full_name='allego.SpkSortTrainerDatasetParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bioPathTrain', full_name='allego.SpkSortTrainerDatasetParam.bioPathTrain', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bioBaseNameTrain', full_name='allego.SpkSortTrainerDatasetParam.bioBaseNameTrain', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bioPathValidation', full_name='allego.SpkSortTrainerDatasetParam.bioPathValidation', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bioBaseNameValidation', full_name='allego.SpkSortTrainerDatasetParam.bioBaseNameValidation', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bioPathTest', full_name='allego.SpkSortTrainerDatasetParam.bioPathTest', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bioBaseNameTest', full_name='allego.SpkSortTrainerDatasetParam.bioBaseNameTest', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numNeighbors', full_name='allego.SpkSortTrainerDatasetParam.numNeighbors', index=6,
      number=7, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='radiusUm', full_name='allego.SpkSortTrainerDatasetParam.radiusUm', index=7,
      number=8, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxNumSamplesTest', full_name='allego.SpkSortTrainerDatasetParam.maxNumSamplesTest', index=8,
      number=9, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networkMaskingFrac', full_name='allego.SpkSortTrainerDatasetParam.networkMaskingFrac', index=9,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networkInitWeightsStdDev', full_name='allego.SpkSortTrainerDatasetParam.networkInitWeightsStdDev', index=10,
      number=11, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networkInitBiasStdDev', full_name='allego.SpkSortTrainerDatasetParam.networkInitBiasStdDev', index=11,
      number=12, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networkL1lambda', full_name='allego.SpkSortTrainerDatasetParam.networkL1lambda', index=12,
      number=13, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networkHiddenLayerShapeRelInputDim', full_name='allego.SpkSortTrainerDatasetParam.networkHiddenLayerShapeRelInputDim', index=13,
      number=14, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networkNumFeatures2', full_name='allego.SpkSortTrainerDatasetParam.networkNumFeatures2', index=14,
      number=15, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=773,
)


_SPKSORTTRAINERNETWORKTRAININGPARAMS = _descriptor.Descriptor(
  name='SpkSortTrainerNetworkTrainingParams',
  full_name='allego.SpkSortTrainerNetworkTrainingParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='numEpochs', full_name='allego.SpkSortTrainerNetworkTrainingParams.numEpochs', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minibatchSize', full_name='allego.SpkSortTrainerNetworkTrainingParams.minibatchSize', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxNumSamples', full_name='allego.SpkSortTrainerNetworkTrainingParams.maxNumSamples', index=2,
      number=3, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alpha', full_name='allego.SpkSortTrainerNetworkTrainingParams.alpha', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alphaBias', full_name='allego.SpkSortTrainerNetworkTrainingParams.alphaBias', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorTolPretrain', full_name='allego.SpkSortTrainerNetworkTrainingParams.errorTolPretrain', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSamplesTestMSE', full_name='allego.SpkSortTrainerNetworkTrainingParams.numSamplesTestMSE', index=6,
      number=7, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=776,
  serialized_end=965,
)


_SPKSORTTRAINERSTOREDESCRIPTOR = _descriptor.Descriptor(
  name='SpkSortTrainerStoreDescriptor',
  full_name='allego.SpkSortTrainerStoreDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='brainRegion', full_name='allego.SpkSortTrainerStoreDescriptor.brainRegion', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networkSize', full_name='allego.SpkSortTrainerStoreDescriptor.networkSize', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nbrPattern', full_name='allego.SpkSortTrainerStoreDescriptor.nbrPattern', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networkID', full_name='allego.SpkSortTrainerStoreDescriptor.networkID', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numNeighbors', full_name='allego.SpkSortTrainerStoreDescriptor.numNeighbors', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='release', full_name='allego.SpkSortTrainerStoreDescriptor.release', index=5,
      number=6, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=968,
  serialized_end=1231,
)


_SPKSORTTRAINERSETMODEREQ = _descriptor.Descriptor(
  name='SpkSortTrainerSetModeReq',
  full_name='allego.SpkSortTrainerSetModeReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.SpkSortTrainerSetModeReq.mode', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1233,
  serialized_end=1273,
)


_SPKSORTTRAINERCMDREQ = _descriptor.Descriptor(
  name='SpkSortTrainerCmdReq',
  full_name='allego.SpkSortTrainerCmdReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='allego.SpkSortTrainerCmdReq.cmd', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SPKSORTTRAINERCMDREQ_SPKSORTTRAINERCMD,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1276,
  serialized_end=1405,
)


_SPKSORTTRAINERSTATUSREPLY = _descriptor.Descriptor(
  name='SpkSortTrainerStatusReply',
  full_name='allego.SpkSortTrainerStatusReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msgJson', full_name='allego.SpkSortTrainerStatusReply.msgJson', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1407,
  serialized_end=1451,
)

_SPKSORTTRAINERNEWREQ.fields_by_name['dataset'].message_type = _SPKSORTTRAINERDATASETPARAM
_SPKSORTTRAINERNEWREQ.fields_by_name['training'].message_type = _SPKSORTTRAINERNETWORKTRAININGPARAMS
_SPKSORTTRAINERNEWREQ.fields_by_name['store'].message_type = _SPKSORTTRAINERSTOREDESCRIPTOR
_SPKSORTTRAINERDELETEMODELREQ.fields_by_name['release'].enum_type = _SPKSORTTRAINERNETWORKRELEASE
_SPKSORTTRAINERSTOREDESCRIPTOR.fields_by_name['networkSize'].enum_type = _SPKSORTTRAINERNETWORKSIZE
_SPKSORTTRAINERSTOREDESCRIPTOR.fields_by_name['nbrPattern'].enum_type = _SPKSORTTRAINERNEIGHBORPATTERN
_SPKSORTTRAINERSTOREDESCRIPTOR.fields_by_name['release'].enum_type = _SPKSORTTRAINERNETWORKRELEASE
_SPKSORTTRAINERCMDREQ.fields_by_name['cmd'].enum_type = _SPKSORTTRAINERCMDREQ_SPKSORTTRAINERCMD
_SPKSORTTRAINERCMDREQ_SPKSORTTRAINERCMD.containing_type = _SPKSORTTRAINERCMDREQ
DESCRIPTOR.message_types_by_name['SpkSortTrainerNewReq'] = _SPKSORTTRAINERNEWREQ
DESCRIPTOR.message_types_by_name['SpkSortTrainerDeleteModelReq'] = _SPKSORTTRAINERDELETEMODELREQ
DESCRIPTOR.message_types_by_name['SpkSortTrainerDatasetParam'] = _SPKSORTTRAINERDATASETPARAM
DESCRIPTOR.message_types_by_name['SpkSortTrainerNetworkTrainingParams'] = _SPKSORTTRAINERNETWORKTRAININGPARAMS
DESCRIPTOR.message_types_by_name['SpkSortTrainerStoreDescriptor'] = _SPKSORTTRAINERSTOREDESCRIPTOR
DESCRIPTOR.message_types_by_name['SpkSortTrainerSetModeReq'] = _SPKSORTTRAINERSETMODEREQ
DESCRIPTOR.message_types_by_name['SpkSortTrainerCmdReq'] = _SPKSORTTRAINERCMDREQ
DESCRIPTOR.message_types_by_name['SpkSortTrainerStatusReply'] = _SPKSORTTRAINERSTATUSREPLY
DESCRIPTOR.enum_types_by_name['SpkSortTrainerNetworkSize'] = _SPKSORTTRAINERNETWORKSIZE
DESCRIPTOR.enum_types_by_name['SpkSortTrainerNeighborPattern'] = _SPKSORTTRAINERNEIGHBORPATTERN
DESCRIPTOR.enum_types_by_name['SpkSortTrainerNetworkRelease'] = _SPKSORTTRAINERNETWORKRELEASE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpkSortTrainerNewReq = _reflection.GeneratedProtocolMessageType('SpkSortTrainerNewReq', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERNEWREQ,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerNewReq)
  })
_sym_db.RegisterMessage(SpkSortTrainerNewReq)

SpkSortTrainerDeleteModelReq = _reflection.GeneratedProtocolMessageType('SpkSortTrainerDeleteModelReq', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERDELETEMODELREQ,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerDeleteModelReq)
  })
_sym_db.RegisterMessage(SpkSortTrainerDeleteModelReq)

SpkSortTrainerDatasetParam = _reflection.GeneratedProtocolMessageType('SpkSortTrainerDatasetParam', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERDATASETPARAM,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerDatasetParam)
  })
_sym_db.RegisterMessage(SpkSortTrainerDatasetParam)

SpkSortTrainerNetworkTrainingParams = _reflection.GeneratedProtocolMessageType('SpkSortTrainerNetworkTrainingParams', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERNETWORKTRAININGPARAMS,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerNetworkTrainingParams)
  })
_sym_db.RegisterMessage(SpkSortTrainerNetworkTrainingParams)

SpkSortTrainerStoreDescriptor = _reflection.GeneratedProtocolMessageType('SpkSortTrainerStoreDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERSTOREDESCRIPTOR,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerStoreDescriptor)
  })
_sym_db.RegisterMessage(SpkSortTrainerStoreDescriptor)

SpkSortTrainerSetModeReq = _reflection.GeneratedProtocolMessageType('SpkSortTrainerSetModeReq', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERSETMODEREQ,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerSetModeReq)
  })
_sym_db.RegisterMessage(SpkSortTrainerSetModeReq)

SpkSortTrainerCmdReq = _reflection.GeneratedProtocolMessageType('SpkSortTrainerCmdReq', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERCMDREQ,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerCmdReq)
  })
_sym_db.RegisterMessage(SpkSortTrainerCmdReq)

SpkSortTrainerStatusReply = _reflection.GeneratedProtocolMessageType('SpkSortTrainerStatusReply', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERSTATUSREPLY,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerStatusReply)
  })
_sym_db.RegisterMessage(SpkSortTrainerStatusReply)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
